@@ -66,9 +66,12 @@
     ["Expunge" vm-expunge-folder vm-message-list]
     ["Expunge POP Messages" vm-expunge-pop-messages
      (vm-menu-can-expunge-pop-messages-p)]
+    ["Expunge IMAP Messages" vm-expunge-pop-messages
+     (vm-menu-can-expunge-imap-messages-p)]
     "---"
-    ["Visit Folder" vm-visit-folder t]
-    ["Visit POP Folder" vm-visit-pop-folder t]
+    ["Visit Local Folder" vm-visit-folder t]
+    ["Visit POP Folder" vm-visit-pop-folder vm-pop-folder-alist]
+    ["Visit IMAP Folder" vm-visit-imap-folder vm-imap-server-list]
     ["Revert Folder (back to disk version)" vm-revert-buffer
      (vm-menu-can-revert-p)]
     ["Recover Folder (from auto-save file)" vm-recover-file
@@ -680,6 +683,13 @@ set to the command name so that window configuration will be done."
 	(not (eq vm-folder-access-method 'pop)))
     (error nil)))
 
+(defun vm-menu-can-expunge-imap-messages-p ()
+  (condition-case nil
+      (save-excursion
+	(vm-select-folder-buffer)
+	(not (eq vm-folder-access-method 'imap)))
+    (error nil)))
+
 (defun vm-menu-yank-original ()
   (interactive)
   (save-excursion
